@@ -132,7 +132,13 @@ func parse(input string) map[string]string {
 	for _, line := range lines {
 		parts := strings.SplitN(line, "=", 2)
 		if len(parts) >= 2 {
-			pairs[parts[0]] = parts[1]
+			key, value := parts[0], parts[1]
+			_, exists := pairs[key]
+			if strings.HasSuffix(key, "[]") && exists {
+				pairs[key] += "\n" + value
+			} else {
+				pairs[key] = value
+			}
 		}
 	}
 	return pairs
@@ -302,6 +308,9 @@ func main() {
 		}
 		if username != "" {
 			output["username"] = username
+			if pairs["username"] != "" && pairs["username"] != username {
+				fmt.Fprintf(os.Stderr, "Username '%s' is incompatible with OAuth. This frustrates retrieval of stored OAuth credentials. Please remove username from remote URL and unset config key credential.username.\n.", pairs["username"])
+			}
 		}
 		if !token.Expiry.IsZero() {
 			output["password_expiry_utc"] = fmt.Sprintf("%d", token.Expiry.UTC().Unix())
